Documentation
¶
Overview ¶
Package common contains Chainguard shared types exposed to the console.
Index ¶
- Variables
- type UIDPFilter
- func (*UIDPFilter) Descriptor() ([]byte, []int)deprecated
- func (x *UIDPFilter) GetAncestorsOf() string
- func (x *UIDPFilter) GetChildrenOf() string
- func (x *UIDPFilter) GetDescendantsOf() string
- func (x *UIDPFilter) GetIds() []string
- func (x *UIDPFilter) GetInRoot() bool
- func (*UIDPFilter) ProtoMessage()
- func (x *UIDPFilter) ProtoReflect() protoreflect.Message
- func (x *UIDPFilter) Reset()
- func (x *UIDPFilter) String() string
Constants ¶
This section is empty.
Variables ¶
var File_uidp_platform_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type UIDPFilter ¶
type UIDPFilter struct {
// ancestors_of are groups reachable by repeated proceeding from child to parent.
AncestorsOf string `protobuf:"bytes,1,opt,name=ancestors_of,json=ancestorsOf,proto3" json:"ancestors_of,omitempty"`
// descendants_of are groups reachable by repeated proceeding from parent to child.
DescendantsOf string `protobuf:"bytes,2,opt,name=descendants_of,json=descendantsOf,proto3" json:"descendants_of,omitempty"`
// children_of are groups reachable by directly proceeding from parent to children.
ChildrenOf string `protobuf:"bytes,3,opt,name=children_of,json=childrenOf,proto3" json:"children_of,omitempty"`
// in_root resticts responses to root level resources (organizations, user identities)
InRoot bool `protobuf:"varint,4,opt,name=in_root,json=inRoot,proto3" json:"in_root,omitempty"`
// ids are a list of exact UIDPs of records.
Ids []string `protobuf:"bytes,5,rep,name=ids,proto3" json:"ids,omitempty"`
// contains filtered or unexported fields
}
func (*UIDPFilter) Descriptor
deprecated
func (*UIDPFilter) Descriptor() ([]byte, []int)
Deprecated: Use UIDPFilter.ProtoReflect.Descriptor instead.
func (*UIDPFilter) GetAncestorsOf ¶
func (x *UIDPFilter) GetAncestorsOf() string
func (*UIDPFilter) GetChildrenOf ¶
func (x *UIDPFilter) GetChildrenOf() string
func (*UIDPFilter) GetDescendantsOf ¶
func (x *UIDPFilter) GetDescendantsOf() string
func (*UIDPFilter) GetIds ¶ added in v0.1.41
func (x *UIDPFilter) GetIds() []string
func (*UIDPFilter) GetInRoot ¶ added in v0.1.18
func (x *UIDPFilter) GetInRoot() bool
func (*UIDPFilter) ProtoMessage ¶
func (*UIDPFilter) ProtoMessage()
func (*UIDPFilter) ProtoReflect ¶
func (x *UIDPFilter) ProtoReflect() protoreflect.Message
func (*UIDPFilter) Reset ¶
func (x *UIDPFilter) Reset()
func (*UIDPFilter) String ¶
func (x *UIDPFilter) String() string
Click to show internal directories.
Click to hide internal directories.